=================
 Plugin Examples
=================

Here you can find a collection of example code for the various Avocado
Plugin interfaces.

To try them out on a development environment, you may run::

 $ cd <plugin-type>/<plugin-example>
 $ python setup.py develop --user

And to remove them on a development environment, you may run, at the
same directory::

 $ python setup.py develop --uninstall --user
